.. :changelog:

History
-------

0.5.5 (2019-11-14)
==================

* Dependency upgrades

0.5.4 (2019-10-02)
==================

* Dependency upgrades

0.5.3 (2019-08-28)
==================

* Improve documentation
* Refactor settings name ``APPSEARCH_URL`` -> ``APPSEARCH_HOST``

0.5.1 (2019-08-26)
==================

* Improve test coverage
* Improve documentation
* Add serpy as an official dependency
* Bump dependency versions
* Add code of conduct


0.4.2 (2019-08-16)
==================

* Switch to the new official Elastic App Search python client
* Documentation improvements


0.2.3 (2019-08-02)
==================

* Use Pipenv for dependency management
* Configure Dependabot for automatic dependency upgrades
* Remove support for Python 3.4
* Documentation improvements


0.2.2 (2019-07-29)
==================

* Bug fixes
* Documentation improvements


0.1.0 (2019-07-26)
==================

* First release on PyPI.
